@@ -1,7 +1,7 @@
 import urllib
 from tornado import gen, httpclient as hc
 
-from . import AbstractHandler
+from . import AbstractHandler, LOGGER
 
 
 class HttpHandler(AbstractHandler):
@@ -23,6 +23,8 @@ class HttpHandler(AbstractHandler):
 
     @gen.coroutine
     def notify(self, level, alert, value, target=None, ntype=None, rule=None):
+        LOGGER.debug("Handler (%s) %s", self.name, level)
+
         message = self.get_short(level, alert, value, target=target, ntype=ntype, rule=rule)
         data = {'alert': alert.name, 'desc': message, 'level': level}
         if target:
